==> maven-dependency-plugin-3.6.0-source-release.zip: maven-dependency-plugin-3.6.0/src/test/java/org/apache/maven/plugins/dependency/testUtils/stubs/StubUnpackFileMarkerHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.dependency.testUtils.stubs;

import java.io.File;

import org.apache.commons.lang3.StringUtils;
import org.apache.maven.plugins.dependency.fromConfiguration.ArtifactItem;
import org.apache.maven.plugins.dependency.utils.markers.UnpackFileMarkerHandler;

public class StubUnpackFileMarkerHandler extends UnpackFileMarkerHandler {
    public StubUnpackFileMarkerHandler(ArtifactItem artifactItem, File markerFilesDirectory) {
        super(artifactItem, markerFilesDirectory);
    }

    protected File getMarkerFile() {
        File markerFile;
        if (this.artifactItem == null
                || (StringUtils.isEmpty(this.artifactItem.getIncludes())
                        && StringUtils.isEmpty(this.artifactItem.getExcludes()))) {
            markerFile = new StubMarkerFile(
                    this.markerFilesDirectory, this.artifact.getId().replace(':', '-') + ".marker");
        } else {
            int includeExcludeHash = 0;

            if (StringUtils.isNotEmpty(this.artifactItem.getIncludes())) {
                includeExcludeHash += this.artifactItem.getIncludes().hashCode();
            }

            if (StringUtils.isNotEmpty(this.artifactItem.getExcludes())) {
                includeExcludeHash += this.artifactItem.getExcludes().hashCode();
            }

            markerFile = new StubMarkerFile(
                    this.markerFilesDirectory, this.artifact.getId().replace(':', '-') + includeExcludeHash);
        }

        return markerFile;
    }
}

==> maven-dependency-plugin-3.9.0-source-release.zip: maven-dependency-plugin-3.9.0/src/test/java/org/apache/maven/plugins/dependency/testUtils/stubs/StubUnpackFileMarkerHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.dependency.testUtils.stubs;

import java.io.File;

import org.apache.maven.plugins.dependency.fromConfiguration.ArtifactItem;
import org.apache.maven.plugins.dependency.utils.markers.UnpackFileMarkerHandler;

public class StubUnpackFileMarkerHandler extends UnpackFileMarkerHandler {
    public StubUnpackFileMarkerHandler(ArtifactItem artifactItem, File markerFilesDirectory) {
        super(artifactItem, markerFilesDirectory);
    }

    @Override
    protected File getMarkerFile() {
        File markerFile;
        if (this.artifactItem == null
                || this.artifactItem.getIncludes().isEmpty()
                        && this.artifactItem.getExcludes().isEmpty()) {
            markerFile = new StubMarkerFile(
                    this.markerFilesDirectory, this.artifact.getId().replace(':', '-') + ".marker");
        } else {
            int includeExcludeHash = 0;

            if (!this.artifactItem.getIncludes().isEmpty()) {
                includeExcludeHash += this.artifactItem.getIncludes().hashCode();
            }

            if (!this.artifactItem.getExcludes().isEmpty()) {
                includeExcludeHash += this.artifactItem.getExcludes().hashCode();
            }

            markerFile = new StubMarkerFile(
                    this.markerFilesDirectory, this.artifact.getId().replace(':', '-') + includeExcludeHash);
        }

        return markerFile;
    }
}
